# Collect Them All - Complete Program

# v1: Pre-usability testing version
# Has introduction, allows multiple runs and ends on request.

import random

# functions go here...

def numcheck(question, type):

    if type == int:
        error = "Please enter an integer that is more than 0"
    else:
        error = "Please enter a number that is more than 0"

    valid = False
    while not valid:
        try:
            response = type(input(question))
            if response > 0:
                return response
            else:
                print(error)
        except ValueError:
            print(error)

# main routine goes here

# Introduction goes here (displays once only)
print("***** Collect Them All - Modelling Tool *****")
print()

print("This tool allows users to estimate the cost of collecting \n"
      "items to form a complete set.  It assumes that the probability of \n"
      "getting any particular outcome is the same (ie: all outcomes \n"
      "are equally likely.  In reality this is probably not the case \n"
      "so in some ways, this tool gives us a 'best case' scenario when it \n"
      "comes to estimating the cost for an entire set.")

print()

print("To use the tool, either enter a target word or enter the number of unique items.")
last_line = "Then enter the price for one item and choose the number of trials."

print()

# 'main' program below (in while loop to enable multiple runs)

keep_going = ""
while keep_going == "":

    print("-" * len(last_line))

    summary = []
    price_summary = []

    # Ask for price & number of trials
    items = input("Enter a target word of the # of items: ")
    price = numcheck("How much does each purchase cost? $", float)
    trials = numcheck("How many trials would you like? ", int)
    print()

    trials_complete = 0

    # Run program for each trial
    while trials_complete < trials:

        target_list = []
        choice_list = []
        purchase_list = []

        try:
            items = int(items)      # replace with integer checking code from component 5 in due course
            for number in range (1, items + 1):
                target_list.append(number)
                choice_list.append(number)

        except ValueError:
            for letter in items:
                target_list.append(letter)
                if letter not in choice_list:
                    choice_list.append(letter)

        while len(target_list) > 0:
            count = 0
            chosen = random.choice(choice_list)
            purchase_list.append(chosen)
            if chosen in target_list:
                target_list.remove(chosen)

        count += 1
        print("Trial {}:".format(trials_complete + 1), end=" ")
        for item in purchase_list:
            print(item, end=",")
        print()

        total_price = len(purchase_list) * price
        price_summary.append(total_price)
        summary_row = "Trial {}: {} items  \t  Cost: ${:.2f}".format(trials_complete + 1, len(purchase_list), total_price)

        summary.append(summary_row)
        trials_complete += 1

    # Calculate statistics
    price_summary.sort()
    lowest = price_summary[0]
    highest = price_summary[-1]

    average = sum(price_summary)/len(price_summary)

    # Show summary
    print()
    print("***** Summary *****")
    for item in summary:
        print(item, end="\n")

    print()
    print("=" * 50)
    print("***** Statistics *****")
    print("Lowest # of items purchased: {:.0f}".format(lowest))
    print("Highest # of items purchased: {:.0f}".format(highest))
    print("Average # of items purchased: {:.2f}".format(average))
    print()
    print("=" * 50)
    print()

    keep_going = input("Please press <enter> for another 'run' or any key to quit...")

print()
print("Thank you for using this program.  Have a great day")
